@@ -29,9 +29,9 @@
 #define MIOPEN_BACKEND_OPENCL 0
 #define MIOPEN_BACKEND_HIP 1
 #define MIOPEN_MODE_NOGPU 0
-#define MIOPEN_USE_MIOPENTENSILE 0
-#define MIOPEN_USE_MIOPENGEMM 0
 #define MIOPEN_USE_ROCBLAS 1
+#define MIOPEN_USE_HIPBLASLT 1
+#define MIOPEN_USE_ROCTRACER 1
 #define MIOPEN_BUILD_DEV 0
 #define MIOPEN_GPU_SYNC 0
 
@@ -51,18 +51,20 @@
 #define MIOPEN_USE_COMPOSABLEKERNEL 1
 #define MIOPEN_ENABLE_AI_IMMED_MODE_FALLBACK 1
 #define MIOPEN_ENABLE_AI_KERNEL_TUNING 1
+#define MIOPEN_HIP_COMPILER_HAS_OPTION_OFFLOAD_UNIFORM_BLOCK 1
+#define MIOPEN_WORKAROUND_USE_BOOST_FILESYSTEM 0
 
 // "_PACKAGE_" to avoid name contentions: the macros like
 // HIP_VERSION_MAJOR are defined in hip_version.h.
 // clang-format off
 #define HIP_PACKAGE_VERSION_MAJOR 6
-#define HIP_PACKAGE_VERSION_MINOR 0
-#define HIP_PACKAGE_VERSION_PATCH 0
+#define HIP_PACKAGE_VERSION_MINOR 3
+#define HIP_PACKAGE_VERSION_PATCH 42134
 // clang-format on
 
 // clang-format off
 #define MIOPEN_AMD_COMGR_VERSION_MAJOR 2
-#define MIOPEN_AMD_COMGR_VERSION_MINOR 6
+#define MIOPEN_AMD_COMGR_VERSION_MINOR 8
 #define MIOPEN_AMD_COMGR_VERSION_PATCH 0
 // clang-format on
 
@@ -74,19 +76,41 @@
 //     remain in the future)  perform final conversion (and rounding) of FP32
 //     to BF16 results. This affects the main functionality of the library.
 #define MIOPEN_USE_RNE_BFLOAT16 1
-#define MIOPEN_FP8_IEEE_EXPONENT_BIAS 1
+#define MIOPEN_FP8_IEEE_EXPONENT_BIAS 0
 #define MIOPEN_FP8_CLIPPING 1
 
 // clang-format off
 #define MIOPEN_DEFAULT_FIND_MODE DynamicHybrid
+
 // clang-format on
+#define MIOPEN_OFFLINE_COMPILER_PATHS_V2 0
+#if MIOPEN_OFFLINE_COMPILER_PATHS_V2
+
+// APIs to get MIOPEN Compiler Paths generated using ROCM Base install Path
+// This will read the ROCM Base Install Path if it is already generated
+// or (if required), will generate the MIOPEN Compiler Flag Path Values
+// and return the value.
+const char* getAMDGCNAssemblerPath();
+const char* getOpenCLCompilerPath();
+const char* getHIPCompilerPath();
+const char* getOffloadBundlerBinPath();
+
+#define MIOPEN_AMDGCN_ASSEMBLER getAMDGCNAssemblerPath()
+#define HIP_OC_COMPILER getOpenCLCompilerPath()
+#define MIOPEN_HIP_COMPILER getHIPCompilerPath()
+#define MIOPEN_OFFLOADBUNDLER_BIN getOffloadBundlerBinPath()
+#else
 #define MIOPEN_AMDGCN_ASSEMBLER "/opt/rocm/llvm/bin/clang"
-#define HIP_OC_COMPILER "/opt/rocm/llvm/bin/clang"
-#define MIOPEN_HIP_COMPILER "/opt/rocm/llvm/bin/clang++"
+#define HIP_OC_COMPILER "/opt/rocm/llvm/bin/amdclang"
+#define MIOPEN_HIP_COMPILER "/opt/rocm/llvm/bin/amdclang++"
 #define MIOPEN_OFFLOADBUNDLER_BIN "/opt/rocm/llvm/bin/clang-offload-bundler"
+#endif // MIOPEN_OFFLINE_COMPILER_PATHS_V2
+
 #define MIOPEN_CACHE_DIR "~/.cache/miopen/"
 
-#define MIOPEN_USE_GEMM (MIOPEN_USE_MIOPENTENSILE || MIOPEN_USE_MIOPENGEMM || MIOPEN_USE_ROCBLAS)
+#define MIOPEN_USE_SQLITE_PERFDB 0
+
+#define MIOPEN_USE_GEMM (MIOPEN_USE_ROCBLAS || MIOPEN_USE_HIPBLASLT)
 
 // Usage of "defined" operator within macro expansion is undefined behavior,
 // so "defined(NDEBUG)" cannot be used there... unlike the following macro:
@@ -124,7 +148,7 @@
 #if MIOPEN_USE_ROCBLAS
 // clang-format off
 #define MIOPEN_ROCBLAS_VERSION_MAJOR 4
-#define MIOPEN_ROCBLAS_VERSION_MINOR 0
+#define MIOPEN_ROCBLAS_VERSION_MINOR 3
 #define MIOPEN_ROCBLAS_VERSION_PATCH 0
 // clang-format on
 #ifndef MIOPEN_ROCBLAS_VERSION_MAJOR
@@ -146,15 +170,40 @@
      MIOPEN_ROCBLAS_VERSION_PATCH)
 #endif // MIOPEN_USE_ROCBLAS
 
+#if MIOPEN_USE_HIPBLASLT
+// clang-format off
+#define MIOPEN_HIPBLASLT_VERSION_MAJOR 0
+#define MIOPEN_HIPBLASLT_VERSION_MINOR 10
+#define MIOPEN_HIPBLASLT_VERSION_PATCH 0
+// clang-format on
+#ifndef MIOPEN_HIPBLASLT_VERSION_MAJOR
+#define MIOPEN_HIPBLASLT_VERSION_MAJOR 0
+#endif
+#ifndef MIOPEN_HIPBLASLT_VERSION_MINOR
+#define MIOPEN_HIPBLASLT_VERSION_MINOR 0
+#endif
+#ifndef MIOPEN_HIPBLASLT_VERSION_PATCH
+#define MIOPEN_HIPBLASLT_VERSION_PATCH 0
+#endif
+// 3 decimal digits for each number; max fits into 32 bits.
+#if MIOPEN_HIPBLASLT_VERSION_MAJOR > 999 || MIOPEN_HIPBLASLT_VERSION_MAJOR > 999 || \
+    MIOPEN_HIPBLASLT_VERSION_PATCH > 999
+#error "Too big HIPBLASLT version number(s)"
+#endif
+#define MIOPEN_HIPBLASLT_VERSION_FLAT                                                  \
+    ((MIOPEN_HIPBLASLT_VERSION_MAJOR * 1000 + MIOPEN_HIPBLASLT_VERSION_MINOR) * 1000 + \
+     MIOPEN_HIPBLASLT_VERSION_PATCH)
+#endif // MIOPEN_USE_HIPBLASLT
+
 /// WORKAROUND_BOOST_ISSUE_392
 /// Workaround for https://github.com/boostorg/config/issues/392#issuecomment-1109889533
-/// See also https://github.com/ROCmSoftwarePlatform/MIOpen/pull/1490#issuecomment-1109928102,
-/// https://github.com/ROCmSoftwarePlatform/MIOpen/pull/1543
+/// See also https://github.com/ROCm/MIOpen/pull/1490#issuecomment-1109928102,
+/// https://github.com/ROCm/MIOpen/pull/1543
 /// TODO: Remove the W/A as soon we switch to the properly fixed boost.
 #if MIOPEN_BACKEND_HIP
 #include <hip/hip_version.h>
 #endif
 
-#define MIOPEN_GOLDEN_DB_VERSION 18
+#define MIOPEN_GOLDEN_DB_VERSION 20
 
 #endif // GUARD_CONFIG_H_IN
